
TLS implementation must operate in an approved mode of operation
-------

**Description:**

To enforce the maximum amount of security out of the TLS implementation it should always 
suffice the approved mode of operation. 


**Solution:**

See See http://csrc.nist.gov/groups/STM/cmvp/documents/fips140-2/FIPS1402IG.pdf 
for more extended details on how to reach this goal.

	